@@ -58,23 +58,23 @@ class BindingTestCase(unittest.TestCase):
         authnRequest = lasso.LibAuthnRequest()
 
         # Test a string attribute.
-        self.failUnlessEqual(authnRequest.consent, None)
+        self.assertEqual(authnRequest.consent, None)
         authnRequest.consent = lasso.LIB_CONSENT_OBTAINED
-        self.failUnlessEqual(authnRequest.consent, lasso.LIB_CONSENT_OBTAINED)
+        self.assertEqual(authnRequest.consent, lasso.LIB_CONSENT_OBTAINED)
         authnRequest.consent = None
-        self.failUnlessEqual(authnRequest.consent, None)
+        self.assertEqual(authnRequest.consent, None)
 
         # Test a renamed string attribute.
-        self.failUnlessEqual(authnRequest.relayState, None)
+        self.assertEqual(authnRequest.relayState, None)
         authnRequest.relayState = 'Hello World!'
-        self.failUnlessEqual(authnRequest.relayState, 'Hello World!')
+        self.assertEqual(authnRequest.relayState, 'Hello World!')
         authnRequest.relayState = None
-        self.failUnlessEqual(authnRequest.relayState, None)
+        self.assertEqual(authnRequest.relayState, None)
 
         # Test an integer attribute.
-        self.failUnlessEqual(authnRequest.majorVersion, 0)
+        self.assertEqual(authnRequest.majorVersion, 0)
         authnRequest.majorVersion = 314
-        self.failUnlessEqual(authnRequest.majorVersion, 314)
+        self.assertEqual(authnRequest.majorVersion, 314)
 
         del authnRequest
 
@@ -83,43 +83,43 @@ class BindingTestCase(unittest.TestCase):
 
         authnRequest = lasso.LibAuthnRequest()
 
-        self.failUnlessEqual(authnRequest.respondWith, ())
+        self.assertEqual(authnRequest.respondWith, ())
 
         respondWith = []
-        self.failUnlessEqual(len(respondWith), 0)
+        self.assertEqual(len(respondWith), 0)
         respondWith.append('first string')
-        self.failUnlessEqual(len(respondWith), 1)
-        self.failUnlessEqual(respondWith[0], 'first string')
+        self.assertEqual(len(respondWith), 1)
+        self.assertEqual(respondWith[0], 'first string')
         respondWith.append('second string')
-        self.failUnlessEqual(len(respondWith), 2)
-        self.failUnlessEqual(respondWith[0], 'first string')
-        self.failUnlessEqual(respondWith[1], 'second string')
+        self.assertEqual(len(respondWith), 2)
+        self.assertEqual(respondWith[0], 'first string')
+        self.assertEqual(respondWith[1], 'second string')
         respondWith.append('third string')
-        self.failUnlessEqual(len(respondWith), 3)
-        self.failUnlessEqual(respondWith[0], 'first string')
-        self.failUnlessEqual(respondWith[1], 'second string')
-        self.failUnlessEqual(respondWith[2], 'third string')
+        self.assertEqual(len(respondWith), 3)
+        self.assertEqual(respondWith[0], 'first string')
+        self.assertEqual(respondWith[1], 'second string')
+        self.assertEqual(respondWith[2], 'third string')
         authnRequest.respondWith = tuple(respondWith)
-        self.failUnlessEqual(authnRequest.respondWith[0], 'first string')
-        self.failUnlessEqual(authnRequest.respondWith[1], 'second string')
-        self.failUnlessEqual(authnRequest.respondWith[2], 'third string')
-        self.failUnlessEqual(respondWith[0], 'first string')
-        self.failUnlessEqual(respondWith[1], 'second string')
-        self.failUnlessEqual(respondWith[2], 'third string')
+        self.assertEqual(authnRequest.respondWith[0], 'first string')
+        self.assertEqual(authnRequest.respondWith[1], 'second string')
+        self.assertEqual(authnRequest.respondWith[2], 'third string')
+        self.assertEqual(respondWith[0], 'first string')
+        self.assertEqual(respondWith[1], 'second string')
+        self.assertEqual(respondWith[2], 'third string')
         del respondWith
-        self.failUnlessEqual(authnRequest.respondWith[0], 'first string')
-        self.failUnlessEqual(authnRequest.respondWith[1], 'second string')
-        self.failUnlessEqual(authnRequest.respondWith[2], 'third string')
+        self.assertEqual(authnRequest.respondWith[0], 'first string')
+        self.assertEqual(authnRequest.respondWith[1], 'second string')
+        self.assertEqual(authnRequest.respondWith[2], 'third string')
         respondWith = authnRequest.respondWith
-        self.failUnlessEqual(respondWith[0], 'first string')
-        self.failUnlessEqual(respondWith[1], 'second string')
-        self.failUnlessEqual(respondWith[2], 'third string')
+        self.assertEqual(respondWith[0], 'first string')
+        self.assertEqual(respondWith[1], 'second string')
+        self.assertEqual(respondWith[2], 'third string')
         del respondWith
-        self.failUnlessEqual(authnRequest.respondWith[0], 'first string')
-        self.failUnlessEqual(authnRequest.respondWith[1], 'second string')
-        self.failUnlessEqual(authnRequest.respondWith[2], 'third string')
+        self.assertEqual(authnRequest.respondWith[0], 'first string')
+        self.assertEqual(authnRequest.respondWith[1], 'second string')
+        self.assertEqual(authnRequest.respondWith[2], 'third string')
         authnRequest.respondWith = None
-        self.failUnlessEqual(authnRequest.respondWith, ())
+        self.assertEqual(authnRequest.respondWith, ())
 
         del authnRequest
 
@@ -128,50 +128,50 @@ class BindingTestCase(unittest.TestCase):
 
         response = lasso.SamlpResponse()
 
-        self.failUnlessEqual(response.assertion, ())
+        self.assertEqual(response.assertion, ())
 
         assertions = []
-        self.failUnlessEqual(len(assertions), 0)
+        self.assertEqual(len(assertions), 0)
         assertion1 = lasso.SamlAssertion()
         assertion1.assertionId = 'assertion 1'
         assertions.append(assertion1)
-        self.failUnlessEqual(len(assertions), 1)
-        self.failUnlessEqual(assertions[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(assertions[0].assertionId, 'assertion 1')
+        self.assertEqual(len(assertions), 1)
+        self.assertEqual(assertions[0].assertionId, 'assertion 1')
+        self.assertEqual(assertions[0].assertionId, 'assertion 1')
         assertion2 = lasso.SamlAssertion()
         assertion2.assertionId = 'assertion 2'
         assertions.append(assertion2)
-        self.failUnlessEqual(len(assertions), 2)
-        self.failUnlessEqual(assertions[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(assertions[1].assertionId, 'assertion 2')
+        self.assertEqual(len(assertions), 2)
+        self.assertEqual(assertions[0].assertionId, 'assertion 1')
+        self.assertEqual(assertions[1].assertionId, 'assertion 2')
         assertion3 = lasso.SamlAssertion()
         assertion3.assertionId = 'assertion 3'
         assertions.append(assertion3)
-        self.failUnlessEqual(len(assertions), 3)
-        self.failUnlessEqual(assertions[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(assertions[1].assertionId, 'assertion 2')
-        self.failUnlessEqual(assertions[2].assertionId, 'assertion 3')
+        self.assertEqual(len(assertions), 3)
+        self.assertEqual(assertions[0].assertionId, 'assertion 1')
+        self.assertEqual(assertions[1].assertionId, 'assertion 2')
+        self.assertEqual(assertions[2].assertionId, 'assertion 3')
         response.assertion = tuple(assertions)
-        self.failUnlessEqual(response.assertion[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(response.assertion[1].assertionId, 'assertion 2')
-        self.failUnlessEqual(response.assertion[2].assertionId, 'assertion 3')
-        self.failUnlessEqual(assertions[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(assertions[1].assertionId, 'assertion 2')
-        self.failUnlessEqual(assertions[2].assertionId, 'assertion 3')
+        self.assertEqual(response.assertion[0].assertionId, 'assertion 1')
+        self.assertEqual(response.assertion[1].assertionId, 'assertion 2')
+        self.assertEqual(response.assertion[2].assertionId, 'assertion 3')
+        self.assertEqual(assertions[0].assertionId, 'assertion 1')
+        self.assertEqual(assertions[1].assertionId, 'assertion 2')
+        self.assertEqual(assertions[2].assertionId, 'assertion 3')
         del assertions
-        self.failUnlessEqual(response.assertion[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(response.assertion[1].assertionId, 'assertion 2')
-        self.failUnlessEqual(response.assertion[2].assertionId, 'assertion 3')
+        self.assertEqual(response.assertion[0].assertionId, 'assertion 1')
+        self.assertEqual(response.assertion[1].assertionId, 'assertion 2')
+        self.assertEqual(response.assertion[2].assertionId, 'assertion 3')
         assertions = response.assertion
-        self.failUnlessEqual(assertions[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(assertions[1].assertionId, 'assertion 2')
-        self.failUnlessEqual(assertions[2].assertionId, 'assertion 3')
+        self.assertEqual(assertions[0].assertionId, 'assertion 1')
+        self.assertEqual(assertions[1].assertionId, 'assertion 2')
+        self.assertEqual(assertions[2].assertionId, 'assertion 3')
         del assertions
-        self.failUnlessEqual(response.assertion[0].assertionId, 'assertion 1')
-        self.failUnlessEqual(response.assertion[1].assertionId, 'assertion 2')
-        self.failUnlessEqual(response.assertion[2].assertionId, 'assertion 3')
+        self.assertEqual(response.assertion[0].assertionId, 'assertion 1')
+        self.assertEqual(response.assertion[1].assertionId, 'assertion 2')
+        self.assertEqual(response.assertion[2].assertionId, 'assertion 3')
         response.assertion = None
-        self.failUnlessEqual(response.assertion, ())
+        self.assertEqual(response.assertion, ())
 
         del response
 
@@ -180,7 +180,7 @@ class BindingTestCase(unittest.TestCase):
 
         authnRequest = lasso.LibAuthnRequest()
 
-        self.failUnlessEqual(authnRequest.extension, ())
+        self.assertEqual(authnRequest.extension, ())
 
         actionString1 = """\
 <lib:Extension xmlns:lib="urn:liberty:iff:2003-08">
@@ -195,41 +195,41 @@ class BindingTestCase(unittest.TestCase):
   <action>do 3</action>
 </lib:Extension>"""
         extension = []
-        self.failUnlessEqual(len(extension), 0)
+        self.assertEqual(len(extension), 0)
         extension.append(actionString1)
-        self.failUnlessEqual(len(extension), 1)
-        self.failUnlessEqual(extension[0], actionString1)
-        self.failUnlessEqual(extension[0], actionString1)
+        self.assertEqual(len(extension), 1)
+        self.assertEqual(extension[0], actionString1)
+        self.assertEqual(extension[0], actionString1)
         extension.append(actionString2)
-        self.failUnlessEqual(len(extension), 2)
-        self.failUnlessEqual(extension[0], actionString1)
-        self.failUnlessEqual(extension[1], actionString2)
+        self.assertEqual(len(extension), 2)
+        self.assertEqual(extension[0], actionString1)
+        self.assertEqual(extension[1], actionString2)
         extension.append(actionString3)
-        self.failUnlessEqual(len(extension), 3)
-        self.failUnlessEqual(extension[0], actionString1)
-        self.failUnlessEqual(extension[1], actionString2)
-        self.failUnlessEqual(extension[2], actionString3)
+        self.assertEqual(len(extension), 3)
+        self.assertEqual(extension[0], actionString1)
+        self.assertEqual(extension[1], actionString2)
+        self.assertEqual(extension[2], actionString3)
         authnRequest.extension = tuple(extension)
-        self.failUnlessEqual(authnRequest.extension[0], actionString1)
-        self.failUnlessEqual(authnRequest.extension[1], actionString2)
-        self.failUnlessEqual(authnRequest.extension[2], actionString3)
-        self.failUnlessEqual(extension[0], actionString1)
-        self.failUnlessEqual(extension[1], actionString2)
-        self.failUnlessEqual(extension[2], actionString3)
+        self.assertEqual(authnRequest.extension[0], actionString1)
+        self.assertEqual(authnRequest.extension[1], actionString2)
+        self.assertEqual(authnRequest.extension[2], actionString3)
+        self.assertEqual(extension[0], actionString1)
+        self.assertEqual(extension[1], actionString2)
+        self.assertEqual(extension[2], actionString3)
         del extension
-        self.failUnlessEqual(authnRequest.extension[0], actionString1)
-        self.failUnlessEqual(authnRequest.extension[1], actionString2)
-        self.failUnlessEqual(authnRequest.extension[2], actionString3)
+        self.assertEqual(authnRequest.extension[0], actionString1)
+        self.assertEqual(authnRequest.extension[1], actionString2)
+        self.assertEqual(authnRequest.extension[2], actionString3)
         extension = authnRequest.extension
-        self.failUnlessEqual(extension[0], actionString1)
-        self.failUnlessEqual(extension[1], actionString2)
-        self.failUnlessEqual(extension[2], actionString3)
+        self.assertEqual(extension[0], actionString1)
+        self.assertEqual(extension[1], actionString2)
+        self.assertEqual(extension[2], actionString3)
         del extension
-        self.failUnlessEqual(authnRequest.extension[0], actionString1)
-        self.failUnlessEqual(authnRequest.extension[1], actionString2)
-        self.failUnlessEqual(authnRequest.extension[2], actionString3)
+        self.assertEqual(authnRequest.extension[0], actionString1)
+        self.assertEqual(authnRequest.extension[1], actionString2)
+        self.assertEqual(authnRequest.extension[2], actionString3)
         authnRequest.extension = None
-        self.failUnlessEqual(authnRequest.extension, ())
+        self.assertEqual(authnRequest.extension, ())
 
         del authnRequest
 
@@ -242,12 +242,12 @@ class BindingTestCase(unittest.TestCase):
             None,
             os.path.join(dataDir, 'sp1-la/certificate.pem')))
 
-        self.failUnlessEqual(login.request, None)
+        self.assertEqual(login.request, None)
         login.request = lasso.LibAuthnRequest()
         login.request.consent = lasso.LIB_CONSENT_OBTAINED
-        self.failUnlessEqual(login.request.consent, lasso.LIB_CONSENT_OBTAINED)
+        self.assertEqual(login.request.consent, lasso.LIB_CONSENT_OBTAINED)
         login.request = None
-        self.failUnlessEqual(login.request, None)
+        self.assertEqual(login.request, None)
 
         del login
 
@@ -258,21 +258,21 @@ class BindingTestCase(unittest.TestCase):
         a = sys.getrefcount(s._cptr)
         del(s)
         b = sys.getrefcount(cptr)
-        self.failUnlessEqual(b, a-1)
+        self.assertEqual(b, a-1)
 
     def test08(self):
         '''Test an integer attribute'''
         authnRequest = lasso.LibAuthnRequest()
         authnRequest.majorVersion = 314
-        self.failUnlessEqual(authnRequest.majorVersion, 314)
+        self.assertEqual(authnRequest.majorVersion, 314)
 
     def test09(self):
         '''Test dictionary attributes'''
         identity = lasso.Identity.newFromDump(open(
                     os.path.join(dataDir, 'sample-identity-dump-1.xml')).read())
-        self.failUnlessEqual(len(identity.federations.keys()), 2)
-        self.failIf(not 'http://idp1.lasso.lan' in identity.federations.keys())
-        self.failUnlessEqual(
+        self.assertEqual(len(identity.federations.keys()), 2)
+        self.assertFalse(not 'http://idp1.lasso.lan' in identity.federations.keys())
+        self.assertEqual(
                 identity.federations['http://idp1.lasso.lan'].localNameIdentifier.content,
                 'first name id')
 
@@ -329,8 +329,29 @@ class BindingTestCase(unittest.TestCase):
         node.sessionIndexes = ()
         assert node.sessionIndexes == (), node.sessionIndexes
 
+    def test14(self):
+        # verify Error implementation
+        with self.assertRaises(lasso.Error) as cm:
+            lasso.Server('', '', '')
+        assert isinstance(str(cm.exception), str)
+        with self.assertRaises(lasso.Error) as cm:
+            lasso.Error.raise_on_rc(lasso._lasso.XML_ERROR_SCHEMA_INVALID_FRAGMENT)
+        self.assertEqual(str(cm.exception),
+                         '<lasso.XmlSchemaInvalidFragmentError(17): An XML tree does not respect at least an XML schema of its namespaces.>')
 
+    def test_set_list_of_strings(self):
+        node = lasso.Samlp2RequestedAuthnContext()
+        with self.assertRaises(TypeError, msg='value should be a tuple of strings'):
+            node.authnContextClassRef = [None]
 
+    def test_set_list_of_pygobject(self):
+        node = lasso.Saml2Attribute()
+
+        class A:
+            _cptr = None
+        value = [A()]
+        with self.assertRaises(TypeError, msg='value should be a tuple of PyGobject'):
+            node.attributeValue = value
 
 bindingSuite = unittest.makeSuite(BindingTestCase, 'test')
 
