@@ -783,206 +783,6 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
 #define LASSO_NAME_IDENTIFIER_MAPPING_ERROR_FORBIDDEN_CALL_ON_THIS_SIDE -901
 #define LASSO_NAME_IDENTIFIER_MAPPING_ERROR_MISSING_TARGET_IDENTIFIER -902
 
-/* Data Service */
-#define LASSO_DATA_SERVICE_ERROR_UNREGISTERED_DST    -1000
-#define LASSO_DATA_SERVICE_ERROR_CANNOT_ADD_ITEM           -1001
-
-/* WSF Profile */
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_CORRELATION:
- *
- * Correlation SOAP Header is missing
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_CORRELATION -1100
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_SECURITY:
- *
- * Security SOAP Header is missing
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_SECURITY -1101
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_ASSERTION_ID:
- *
- * AssertionID attribute is missing
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_ASSERTION_ID -1102
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_ENDPOINT:
- *
- * Cannot find an WSP endpoint for the ID-WSF service
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_ENDPOINT -1103
-/**
- * LASSO_WSF_PROFILE_ERROR_SOAP_FAULT:
- *
- * SOAP ID-WSF binding returned a SOAP fault
- */
-#define LASSO_WSF_PROFILE_ERROR_SOAP_FAULT 1104
-/**
- * LASSO_WSF_PROFILE_ERROR_UNSUPPORTED_SECURITY_MECHANISM:
- *
- * The specified security mechanism is not supported by lasso ID-WSF library
- */
-#define LASSO_WSF_PROFILE_ERROR_UNSUPPORTED_SECURITY_MECHANISM 1105
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_DESCRIPTION:
- *
- * No ID-WSF web Service description could be found for the current security mechanism
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_DESCRIPTION -1106
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_RESOURCE_ID:
- *
- * The necessary ResourceID or EncryptedResourceID for calling an ID-WSF service is missing.
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_RESOURCE_ID -1107
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_CREDENTIAL_REF:
- *
- * WS-Security SAML Token secmech needs a CredentialRef
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_CREDENTIAL_REF -1108
-/**
- * LASSO_WSF_PROFILE_ERROR_INVALID_OR_MISSING_REFERENCE_TO_MESSAGE_ID:
- *
- * refToMessageID attribute of the Corrrelation header does not match the SOAP request
- */
-#define LASSO_WSF_PROFILE_ERROR_INVALID_OR_MISSING_REFERENCE_TO_MESSAGE_ID -1109
-/**
- * LASSO_WSF_PROFILE_ERROR_SECURITY_MECHANISM_CHECK_FAILED:
- *
- * Check for a security mechanism upon a received request failed.
- */
-#define LASSO_WSF_PROFILE_ERROR_SECURITY_MECHANISM_CHECK_FAILED 1110
-
-/**
- * LASSO_WSF_PROFILE_ERROR_UNKNOWN_STATUS_CODE:
- *
- * A response contained an unknown status code.
- */
-#define LASSO_WSF_PROFILE_ERROR_UNKNOWN_STATUS_CODE 1112
-/**
- * LASSO_WSF_PROFILE_ERROR_SERVER_INTERACTION_REQUIRED:
- *
- * A interaction is required but the sender did not allow use to make interact redirect requests.
- */
-#define LASSO_WSF_PROFILE_ERROR_SERVER_INTERACTION_REQUIRED 1113
-/**
- * LASSO_WSF_PROFILE_ERROR_SERVER_INTERACTION_REQUIRED_FOR_DATA:
- *
- * A interaction is required to get fresh datas but the sender did not allow use to make interact
- * redirect requests.
- */
-#define LASSO_WSF_PROFILE_ERROR_SERVER_INTERACTION_REQUIRED_FOR_DATA 1114
-/**
- * LASSO_WSF_PROFILE_ERROR_REDIRECT_REQUEST:
- *
- * The last parsed response contained a SOAP fault with a RedirectRequest element.
- */
-#define LASSO_WSF_PROFILE_ERROR_REDIRECT_REQUEST 1115
-/**
- * LASSO_WSF_PROFILE_ERROR_REDIRECT_REQUEST_UNSUPPORTED_BY_REQUESTER:
- *
- * The requester does not support SOAP Fault containing RedirectRequest elements. So it is not
- * possible to use lasso_idwsf2_profile_redirect_user_for_interaction().
- */
-#define LASSO_WSF_PROFILE_ERROR_REDIRECT_REQUEST_UNSUPPORTED_BY_REQUESTER 1116
-/**
- * LASSO_WSF_PROFILE_ERROR_MISSING_SENDER_ID:
- *
- * The received ID-WSF request miss a Sender id.
- */
-#define LASSO_WSF_PROFILE_ERROR_MISSING_SENDER_ID 1117
-
-
-/* ID-WSF 2 Discovery */
-/**
- * LASSO_DISCOVERY_ERROR_SVC_METADATA_REGISTER_FAILED:
- *
- * Service metadata registration failed
- */
-#define LASSO_DISCOVERY_ERROR_SVC_METADATA_REGISTER_FAILED -1200
-/**
- * LASSO_DISCOVERY_ERROR_SVC_METADATA_ASSOCIATION_ADD_FAILED:
- *
- * Service metadata association failed
- */
-#define LASSO_DISCOVERY_ERROR_SVC_METADATA_ASSOCIATION_ADD_FAILED -1201
-/**
- * LASSO_DISCOVERY_ERROR_MISSING_REQUESTED_SERVICE:
- *
- * Missing requested service
- */
-#define LASSO_DISCOVERY_ERROR_MISSING_REQUESTED_SERVICE -1202
-/**
- * LASSO_DISCOVERY_ERROR_FAILED_TO_BUILD_ENDPOINT_REFERENCE:
- *
- * Failed to build Endpoint Reference
- */
-#define LASSO_DISCOVERY_ERROR_FAILED_TO_BUILD_ENDPOINT_REFERENCE -1203
-
-/* ID-WSF 2 Data Service */
-/**
- * LASSO_DST_ERROR_MISSING_SERVICE_DATA:
- *
- * Missing service data
- */
-#define LASSO_DST_ERROR_MISSING_SERVICE_DATA -1300
-/**
- * LASSO_DST_ERROR_QUERY_FAILED:
- *
- * Query failed
- */
-#define LASSO_DST_ERROR_QUERY_FAILED -1301
-/**
- * LASSO_DST_ERROR_QUERY_PARTIALLY_FAILED:
- *
- * Query partially failed : some items were correctly processed
- */
-#define LASSO_DST_ERROR_QUERY_PARTIALLY_FAILED -1302
-/**
- * LASSO_DST_ERROR_MODIFY_FAILED:
- *
- * Modify failed
- */
-#define LASSO_DST_ERROR_MODIFY_FAILED -1303
-/**
- * LASSO_DST_ERROR_MODIFY_PARTIALLY_FAILED:
- *
- * Modify partially failed : some items were correctly processed
- */
-#define LASSO_DST_ERROR_MODIFY_PARTIALLY_FAILED -1304
-/**
- * LASSO_DST_ERROR_NEW_DATA_MISSING:
- *
- * Missing new data
- */
-#define LASSO_DST_ERROR_NEW_DATA_MISSING -1305
-/**
- * LASSO_DST_ERROR_QUERY_NOT_FOUND:
- *
- * Looked query is not found
- */
-#define LASSO_DST_ERROR_QUERY_NOT_FOUND -1306
-/**
- * LASSO_DST_ERROR_NO_DATA:
- *
- * No data or no data for the designated query item in the query response
- */
-#define LASSO_DST_ERROR_NO_DATA -1307
-/**
- * LASSO_DST_ERROR_MALFORMED_QUERY:
- *
- * QueryObject is malformed
- */
-#define LASSO_DST_ERROR_MALFORMED_QUERY -1308
-/**
- * LASSO_DST_ERROR_EMPTY_REQUEST
- *
- * Request is empty.
- */
-#define LASSO_DST_ERROR_EMPTY_REQUEST -1309
-
 /* Lasso registry */
 /**
  * LASSO_REGISTRY_ERROR_KEY_EXISTS:
@@ -999,88 +799,6 @@ LASSO_EXPORT const char* lasso_strerror(int error_code);
  */
 #define LASSO_PROVIDER_ERROR_MISSING_PUBLIC_KEY -1500
 
-/* WS-Security */
-/**
- * LASSO_WSSEC_ERROR_MISSING_SECURITY_TOKEN:
- *
- * The request miss a WS-Security token.
- */
-#define LASSO_WSSEC_ERROR_MISSING_SECURITY_TOKEN 1600
-
-/**
- * LASSO_WSSEC_ERROR_BAD_PASSWORD:
- *
- * The known password does not match the UsernameToken
- */
-#define LASSO_WSSEC_ERROR_BAD_PASSWORD 1601
-
-/* ID-WSF 2.0 Discovery Service */
-/**
- * LASSO_IDWSF2_DISCOVERY_ERROR_FAILED:
- *
- * Last discovery request failed.
- */
-#define LASSO_IDWSF2_DISCOVERY_ERROR_FAILED 1700
-/**
- * LASSO_IDWSF2_DISCOVERY_ERROR_FORBIDDEN:
- *
- * Last discovery request is forbidden by policy.
- */
-#define LASSO_IDWSF2_DISCOVERY_ERROR_FORBIDDEN 1701
-/**
- * LASSO_IDWSF2_DISCOVERY_ERROR_DUPLICATE:
- *
- * Last discovery request was denied because it would result in duplicate data in the service
- */
-#define LASSO_IDWSF2_DISCOVERY_ERROR_DUPLICATE 1702
-/**
- * LASSO_IDWSF2_DISCOVERY_ERROR_LOGICAL_DUPLICATE:
- *
- * Last discovery request was denied because it would result in logically duplicate data in the service
- */
-#define LASSO_IDWSF2_DISCOVERY_ERROR_LOGICAL_DUPLICATE 1703
-/**
- * LASSO_IDWSF2_DISCOVERY_ERROR_NO_RESULTS:
- *
- * The discovery query had no matching results.
- */
-#define LASSO_IDWSF2_DISCOVERY_ERROR_NO_RESULTS 1704
-/**
- * LASSO_IDWSF2_DISCOVERY_ERROR_NOT_FOUND:
- *
- * The specified item(s) were not found.
- */
-#define LASSO_IDWSF2_DISCOVERY_ERROR_NOT_FOUND 1705
-
-/* ID-WSF 2.0 Data Service Template */
-
-/**
- * LASSO_IDWSF2_DST_ERROR_DUPLICATE_ITEM:
- *
- * A call to add a new item would result in duplicate items.
- */
-#define LASSO_IDWSF2_DST_ERROR_DUPLICATE_ITEM -1801
-
-/**
- * LASSO_IDWSF2_DST_ERROR_PARTIAL_FAILURE:
- *
- * Server responded with a partial failure status code.
- */
-#define LASSO_IDWSF2_DST_ERROR_PARTIAL_FAILURE 1802
-
-/**
- * LASSO_IDWSF2_DST_ERROR_UNKNOWN_STATUS_CODE:
- *
- * Server response with an unknown status code.
- */
-#define LASSO_IDWSF2_DST_ERROR_UNKNOWN_STATUS_CODE 1803
-/**
- * LASSO_IDWSF2_DST_ERROR_ITEM_NOT_FOUND:
- *
- * The item_id was not found in the current query request.
- */
-#define LASSO_IDWSF2_DST_ERROR_ITEM_NOT_FOUND 1804
-
 /**
  * LASSO_ASSERTION_QUERY_ERROR_ATTRIBUTE_REQUEST_ALREADY_EXIST:
  *
