@@ -882,7 +882,7 @@ dispose(GObject *object)
 /*****************************************************************************/
 
 static void
-instance_init(LassoProvider *provider)
+instance_init(LassoProvider *provider, G_GNUC_UNUSED void *unused)
 {
 	provider->role = LASSO_PROVIDER_ROLE_NONE;
 	provider->ProviderID = NULL;
@@ -1434,12 +1434,12 @@ lasso_provider_verify_signature(LassoProvider *provider,
 
 	if (format == LASSO_MESSAGE_FORMAT_BASE64) {
 		int len;
-		char *msg = g_malloc(strlen(message));
-		len = xmlSecBase64Decode((xmlChar*)message, (xmlChar*)msg, strlen(message));
-		if (len < 0) {
+		char *msg = NULL;
+
+		if (! lasso_base64_decode(message, &msg, &len)) {
 			goto_cleanup_with_rc(LASSO_PROFILE_ERROR_INVALID_MSG);
 		}
-		doc = lasso_xml_parse_memory(msg, strlen(msg));
+		doc = lasso_xml_parse_memory(msg, len);
 		lasso_release_string(msg);
 	} else {
 		doc = lasso_xml_parse_memory(message, strlen(message));
@@ -1592,7 +1592,7 @@ lasso_provider_get_key_encryption_method(const LassoProvider *provider)
 int
 lasso_provider_verify_query_signature(LassoProvider *provider, const char *message)
 {
-	int (*check)(const char *, const xmlSecKey *) = NULL;
+	int (*check)(const char *, xmlSecKey *) = NULL;
 	int rc = 0;
 	int signature_rc = 0;
 	GList *public_keys = NULL;
