@@ -49,7 +49,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoLibAuthnResponseEnvelopeClass *klass)
+class_init(LassoLibAuthnResponseEnvelopeClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
