@@ -75,7 +75,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoLibNameIdentifierMappingRequestClass *klass)
+class_init(LassoLibNameIdentifierMappingRequestClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
