@@ -71,7 +71,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoLibNameIdentifierMappingResponseClass *klass)
+class_init(LassoLibNameIdentifierMappingResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
