@@ -18,14 +18,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <libxml/tree.h>
 #include "../utils.h"
-#include "./private.h"
-#include "./misc_text_node.h"
+#include "private.h"
+#include "misc_text_node.h"
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -33,6 +32,7 @@
 
 typedef struct {
 	xmlNode *xml_content;
+	GHashTable *any_attributes;
 } LassoMiscTextNodePrivate;
 
 #define LASSO_MISC_TEXT_NODE_GET_PRIVATE(o) \
@@ -41,30 +41,19 @@ typedef struct {
 static struct XmlSnippet schema_snippets[] = {
 	{ "content", SNIPPET_TEXT_CHILD,
 		G_STRUCT_OFFSET(LassoMiscTextNode, content), NULL, NULL, NULL},
+	{ "any_attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY | SNIPPET_PRIVATE,
+		G_STRUCT_OFFSET(LassoMiscTextNodePrivate, any_attributes), NULL, NULL, NULL},
 	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
 
-
-static void
-insure_namespace(xmlNode *xmlnode, xmlNs *ns)
-{
-	xmlNode *t = xmlnode->children;
-
-	xmlSetNs(xmlnode, ns);
-	while (t) {
-		if (t->type == XML_ELEMENT_NODE && t->ns == NULL)
-			insure_namespace(t, ns);
-		t = t->next;
-	}
-}
-
 static xmlNode*
 get_xmlNode(LassoNode *node, gboolean lasso_dump)
 {
 	xmlNode *xmlnode;
 	xmlNs *ns;
+	LassoMiscTextNode *mtnode = (LassoMiscTextNode*)node;
 	LassoMiscTextNodePrivate *private;
 
 	private = LASSO_MISC_TEXT_NODE_GET_PRIVATE(node);
@@ -77,10 +66,12 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 	}
 
 	xmlnode = parent_class->get_xmlNode(node, lasso_dump);
-	xmlNodeSetName(xmlnode, (xmlChar*)LASSO_MISC_TEXT_NODE(node)->name);
-	ns = xmlNewNs(xmlnode, (xmlChar*)LASSO_MISC_TEXT_NODE(node)->ns_href,
-			(xmlChar*)LASSO_MISC_TEXT_NODE(node)->ns_prefix);
-	insure_namespace(xmlnode, ns);
+	xmlNodeSetName(xmlnode, BAD_CAST mtnode->name);
+	if (! lasso_strisempty(mtnode->ns_href) && ! lasso_strisempty(mtnode->ns_href)) {
+		ns = xmlNewNs(xmlnode, BAD_CAST mtnode->ns_href,
+				BAD_CAST mtnode->ns_prefix);
+		xmlSetNs(xmlnode, ns);
+	}
 
 	return xmlnode;
 }
@@ -95,15 +86,21 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 		n->text_child = TRUE;
 		n->content = g_strdup((char*)(xmlnode->content));
 		return 0;
+	} else if (xmlnode->type == XML_ELEMENT_NODE && xmlnode->properties == NULL &&
+			(xmlnode->children == NULL
+				|| (xmlnode->children != NULL && xmlnode->children->next == NULL &&
+					xmlnode->children->type == XML_TEXT_NODE)))
+	{
+		rc = parent_class->init_from_xml(node, xmlnode);
+		if (rc) return rc;
+
+		n->ns_href = g_strdup((char*)xmlnode->ns->href);
+		n->ns_prefix = g_strdup((char*)xmlnode->ns->prefix);
+		n->name = g_strdup((char*)xmlnode->name);
+	} else {
+		lasso_misc_text_node_set_xml_content(n, xmlnode);
 	}
 
-	rc = parent_class->init_from_xml(node, xmlnode);
-	if (rc) return rc;
-
-	n->ns_href = g_strdup((char*)xmlnode->ns->href);
-	n->ns_prefix = g_strdup((char*)xmlnode->ns->prefix);
-	n->name = g_strdup((char*)xmlnode->name);
-
 	return 0;
 }
 
@@ -129,7 +126,7 @@ finalize(GObject *object)
 
 
 static void
-class_init(LassoMiscTextNodeClass *klass)
+class_init(LassoMiscTextNodeClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -176,7 +173,7 @@ lasso_misc_text_node_get_type()
  *
  * Return the xml content in this node.
  *
- * Return value: an #xmlNode or NULL.
+ * Return value:(transfer none): an #xmlNode or NULL.
  */
 xmlNode*
 lasso_misc_text_node_get_xml_content(LassoMiscTextNode *misc_text_node)
