@@ -55,7 +55,7 @@ static LassoNodeClass *parent_class = NULL;
 /*****************************************************************************/
 
 static void
-class_init(LassoSamlp2LogoutResponseClass *klass)
+class_init(LassoSamlp2LogoutResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
