@@ -106,7 +106,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 
 
 static void
-class_init(LassoSamlp2ResponseClass *klass)
+class_init(LassoSamlp2ResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
