@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __LASSO_SAML_ADVICE_H__
@@ -52,8 +51,7 @@ struct _LassoSamlAdvice {
 	/* <element ref="saml:AssertionIDReference"/> */
 	GList *AssertionIDReference; /* of LassoNode */
 	/* <element ref="saml:Assertion"/> */
-	LassoNode *Assertion; /* actually LassoSamlAssertion* but it recurses */
-
+	struct _LassoSamlAssertion *Assertion;
 };
 
 struct _LassoSamlAdviceClass {
