@@ -61,7 +61,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoSamlAuthorityBindingClass *klass)
+class_init(LassoSamlAuthorityBindingClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
