@@ -108,7 +108,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 
 
 static void
-class_init(LassoSamlpResponseClass *klass)
+class_init(LassoSamlpResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
