@@ -77,7 +77,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoSoapFaultClass *klass)
+class_init(LassoSoapFaultClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
